Projects
========

.. toctree::
    :hidden:

    IntroProjects.rst
    scaffolded_code.rst
    turtle_driving.rst 
    input_compute_output.rst   
    drawing_a_circle.rst
    xkcd_pass.rst
    kiva_statistics.rst
    kiva_graphs.rst
    graphing_with_altair.rst
    encryption.rst
    image_processing.rst
    common_words.rst
    monte_carlo_simulations.rst
    roman_numerals.rst
    split_apply_combine.rst
    image_processing_revisited.rst
    l_systems.rst
    regression_analysis.rst
    diy_google.rst
    better_pizza_predictions.rst
    clustering.rst
    sentiment_analysis.rst
    jupyterlite.rst

